@@ -7,6 +7,13 @@ mod tests {
     use crate::stats::BasicPremade as BasicPremade;
     use crate::stats::NormalPremade as NormalPremade;
     use crate::legendary::Legendary;
+    use crate::types::Special;
+
+    #[test]
+    fn special_type(){
+        let grind:Special = Special::Grind;
+        assert_eq!(grind.mp_cost(),7.0);
+    }
     // used in tests below
     pub struct Character {
         pub name:String,
@@ -127,7 +134,7 @@ mod tests {
         let mut enemy:Character = Character::empty();
         // enemy has 5 hp
         //TODO breaking change
-        enemy.stats = Stats::from_class(1.0, enemy.class);
+        enemy.stats = enemy.class.build_basic(1.0,1.0);
         assert_eq!(enemy.hp_max(), 5.0);
         // now it has one less
         enemy.damage(1.0);
